plugin Package
==============

:mod:`plugin` Module
~~~~~~~~~~~~~~~~~~~~

.. automodule:: pynsive.plugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`loader` Module
~~~~~~~~~~~~~~~~~~~~

.. automodule:: pynsive.plugin.loader
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`manager` Module
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pynsive.plugin.manager
    :members:
    :undoc-members:
    :show-inheritance:

